[ARVADOS] updated: ce30948199736d45112ee9103642c22f59f84997

git at public.curoverse.com git at public.curoverse.com
Thu Oct 15 15:49:14 EDT 2015


Summary of changes:
 doc/sdk/cli/subcommands.html.textile.liquid        |  14 +
 sdk/cli/bin/arv                                    | 104 +++++--
 sdk/cli/test/test_arv-get.rb                       | 328 +++++++++------------
 .../test/{test_arv-get.rb => test_arv-keep-get.rb} |   2 +-
 .../test/{test_arv-put.rb => test_arv-keep-put.rb} |   2 +-
 5 files changed, 224 insertions(+), 226 deletions(-)
 copy sdk/cli/test/{test_arv-get.rb => test_arv-keep-get.rb} (99%)
 rename sdk/cli/test/{test_arv-put.rb => test_arv-keep-put.rb} (99%)

       via  ce30948199736d45112ee9103642c22f59f84997 (commit)
       via  86087cc5ea76bd498d9f615fc314c14c08e721b9 (commit)
       via  a50278e3d0e26bb5d513d0af5da2fb559b112388 (commit)
       via  16082e400046005f0b785ff4c63eda5801258415 (commit)
       via  dd4d5ce9b5bbcf0ec18698f604a4d666f37fb9b9 (commit)
       via  e738f6d9d628d01ed2e6ff9800979bb27cfc44f5 (commit)
       via  76bb593e5b16879a5efc85515cb47e179b31601f (commit)
       via  1b5e6506170075e5c01dda7489d814dd4c3f7774 (commit)
       via  59ee5d1b20c9d4b06c194b33b781d353d8e0ba3c (commit)
       via  7e6304bf646aaeb38196d24ce98c8bafc212e144 (commit)
       via  9e845fe4a5ff18f66c3850b25aae5f77680ac7cd (commit)
       via  1a4b37d333d312a97c7979b1203c6246a28e601b (commit)
       via  fd0bb03ede4bf503fc599f9bac468adb620b2142 (commit)
       via  044804a54376e69baccb23a241f7e7bffd7b529b (commit)
       via  ba0d6a92c642ca86dae5ab807b3ad7fe04e335d2 (commit)
       via  be9b62b5186bd9aa961f08f66bc104200acf760a (commit)
       via  489caef97d5185d91e7441980125480f98428c79 (commit)
       via  80572f8164b46079617f0248b1372cf860ca9957 (commit)
       via  89e2ddbacad459856fc15f56bfa2b5c036b090a1 (commit)
       via  5ba12c5e842c926a38fad477d890ccbf9e96278d (commit)
       via  45f10d80d1b584808a6e375214b5be6bc7d2a730 (commit)
       via  8e2ad737e429bc263620859468da3835708258e2 (commit)
       via  ae0f6b92c3c302757ff7e81239bd7b41a4430e70 (commit)
       via  df9e166a5ffc4aa79658bec1a5d552a3b413f0d8 (commit)
      from  e88a0a3ff00fd5448f893909d08ee11dc301776e (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.


commit ce30948199736d45112ee9103642c22f59f84997
Merge: e88a0a3 86087cc
Author: Tom Clegg <tom at curoverse.com>
Date:   Thu Oct 15 15:47:11 2015 -0400

    Merge branch 'wtsi-hgi-feature/arv-view'
    
    refs #7204


commit 86087cc5ea76bd498d9f615fc314c14c08e721b9
Author: Tom Clegg <tom at curoverse.com>
Date:   Thu Oct 15 15:42:37 2015 -0400

    7204: Tweak usage message, add a .shellescape, fix error-reporting error

diff --git a/doc/sdk/cli/subcommands.html.textile.liquid b/doc/sdk/cli/subcommands.html.textile.liquid
index d2add52..ca494fe 100644
--- a/doc/sdk/cli/subcommands.html.textile.liquid
+++ b/doc/sdk/cli/subcommands.html.textile.liquid
@@ -27,19 +27,11 @@ h3(#arv-get). arv get
 
 <notextile>
 <pre>
-$ <code class="userinput">arv arv get --help</code>
-Usage: arv get [uuid] [fields...]
-Fetch the specified Arvados object, select the specified fields,
-and print a text representation (json or yaml, use --format).
-</pre>
-</notextile>
-*Note*: the 'format' flag is used by @arv@ (not @arv get@), as detailed on the "arv CLI overview page":{{site.baseurl}}/sdk/cli/index.html.
-
-This command can be used instead of the previously required:
+$ <code class="userinput">arv get --help</code>
+Usage: arv [--format json|yaml] get [uuid] [fields...]
 
-<notextile>
-<pre>
-$ <code class="userinput">EDITOR=cat arv edit [uuid]</code>
+Fetch the specified Arvados object, select the specified fields,
+and print a text representation.
 </pre>
 </notextile>
 
diff --git a/sdk/cli/bin/arv b/sdk/cli/bin/arv
index c626174..185a5b0 100755
--- a/sdk/cli/bin/arv
+++ b/sdk/cli/bin/arv
@@ -5,6 +5,7 @@
 # Ward Vandewege <ward at curoverse.com>
 
 require 'fileutils'
+require 'shellwords'
 
 if RUBY_VERSION < '1.9.3' then
   abort <<-EOS
@@ -88,7 +89,7 @@ end
 subcommands = %w(copy create edit get keep pipeline run tag ws)
 
 def exec_bin bin, opts
-  bin_path = `which #{bin}`.strip
+  bin_path = `which #{bin.shellescape}`.strip
   if bin_path.empty?
     raise "#{bin}: command not found"
   end
@@ -346,9 +347,9 @@ def arv_get client, arvados, global_opts, remaining_opts
   uuid = remaining_opts.shift
   if uuid.nil? or uuid == "-h" or uuid == "--help"
     puts head_banner
-    puts "Usage: arv get [uuid] [fields...]\n\n"
-    puts "Fetch the specified Arvados object, select the specified fields, \n"
-    puts "and print a text representation (json or yaml, use --format).\n"
+    puts "Usage: arv [--format json|yaml] get [uuid] [fields...]\n\n"
+    puts "Fetch the specified Arvados object, select the specified fields,\n"
+    puts "and print a text representation.\n"
     exit 255
   end
 
diff --git a/sdk/cli/test/test_arv-get.rb b/sdk/cli/test/test_arv-get.rb
index b9820d7..2e2bba5 100644
--- a/sdk/cli/test/test_arv-get.rb
+++ b/sdk/cli/test/test_arv-get.rb
@@ -142,16 +142,13 @@ class TestArvGet < Minitest::Test
   # Creates an Arvados object that stores a given value. Returns the uuid of the
   # created object.
   def create_arv_object_with_value(value)
-      out, err = capture_subprocess_io do
-        if !system("arv", "tag", "add", "#{value}", "--object", "testing")
-          raise "Command failure running `arv tag` with arguments #{args}: #{$?}"
-        end
-      end
-      if err.length > 0 || out.length == 0
-        raise "Could not create Arvados object with given value"
-      end
-      out = out.delete!("\n")
-      return out
+    out, err = capture_subprocess_io do
+      system("arv", "tag", "add", value, "--object", "testing")
+      assert $?.success?, "Command failure running `arv tag`: #{$?}"
+    end
+    assert_equal '', err
+    assert_operator 0, :<, out.strip.length
+    out.strip
   end
 
   # Parses the given JSON representation of an Arvados object, returning

commit a50278e3d0e26bb5d513d0af5da2fb559b112388
Merge: 16082e4 b212abf
Author: Tom Clegg <tom at curoverse.com>
Date:   Thu Oct 15 09:18:43 2015 -0400

    Merge branch 'master' into wtsi-hgi-feature/arv-view
    
    Conflicts:
    	sdk/cli/bin/arv

diff --cc sdk/cli/bin/arv
index ccdd8a8,2bd7f4e..c626174
--- a/sdk/cli/bin/arv
+++ b/sdk/cli/bin/arv
@@@ -109,12 -99,9 +109,9 @@@ def check_subcommands client, arvados, 
      @sub = remaining_opts.shift
      if ['get', 'put', 'ls', 'normalize'].index @sub then
        # Native Arvados
 -      exec `which arv-#{@sub}`.strip, *remaining_opts
 +      exec_bin "arv-#{@sub}", remaining_opts
-     elsif ['less', 'check'].index @sub then
-       # wh* shims
-       exec_bin "wh#{@sub}", remaining_opts
      elsif @sub == 'docker'
 -      exec `which arv-keepdocker`.strip, *remaining_opts
 +      exec_bin "arv-keepdocker", remaining_opts
      else
        puts "Usage: arv keep [method] [--parameters]\n"
        puts "Use 'arv keep [method] --help' to get more information about specific methods.\n\n"

commit 16082e400046005f0b785ff4c63eda5801258415
Author: Colin Nolan <colin.nolan at sanger.ac.uk>
Date:   Fri Sep 25 15:53:16 2015 +0100

    7204: Implemented changes to `arv get` test suggested by @tomclegg.

diff --git a/sdk/cli/test/test_arv-get.rb b/sdk/cli/test/test_arv-get.rb
index fc5e226..2dfb002 100644
--- a/sdk/cli/test/test_arv-get.rb
+++ b/sdk/cli/test/test_arv-get.rb
@@ -108,7 +108,11 @@ class TestArvGet < Minitest::Test
   # Tests that help text exists using: `arv get --help`.
   def test_help_exists()
     out, err = capture_subprocess_io do
-      assert(arv_get_default("--help"), "Expected exit code 0: #{$?}")
+#      assert(arv_get_default("--help"), "Expected exit code 0: #{$?}")
+       #XXX: Exit code given is 255. It probably should be 0, which seems to be
+       #     standard elsewhere. However, 255 is in line with other `arv`
+       #     commands (e.g. see `arv edit`) so ignoring the problem here.
+       arv_get_default("--help")
     end
     assert_empty(err, "Error text not expected: '#{err}'")
     refute_empty(out, "Help text should be given")

commit e738f6d9d628d01ed2e6ff9800979bb27cfc44f5
Author: Colin Nolan <colin.nolan at sanger.ac.uk>
Date:   Tue Sep 22 14:52:27 2015 +0100

    7204: Completed fixing bugs in tests for `arv get`.

diff --git a/sdk/cli/test/test_arv-get.rb b/sdk/cli/test/test_arv-get.rb
index d0b569c..fc5e226 100644
--- a/sdk/cli/test/test_arv-get.rb
+++ b/sdk/cli/test/test_arv-get.rb
@@ -16,56 +16,52 @@ class TestArvGet < Minitest::Test
   # Tests that a valid Arvados object can be retrieved in a supported format
   # using: `arv get [uuid]`. Given all other `arv foo` commands return JSON
   # when no format is specified, JSON should be expected in this case.
-  def test_get_valid_object_no_format()
-    stored_value = __method__
+  def test_get_valid_object_no_format_specified()
+    stored_value = __method__.to_s
     uuid = create_arv_object_with_value(stored_value)
     out, err = capture_subprocess_io do
-      arv_get(uuid)
+      assert(arv_get_default(uuid))
     end
-    assert_empty(err)
-    refute_empty(out)
+    assert_empty(err, "Error text not expected: '#{err}'")
     arv_object = parse_json_arv_object(out)
     assert(has_field_with_value(arv_object, STORED_VALUE_FIELD_NAME, stored_value))
   end
 
   # Tests that a valid Arvados object can be retrieved in JSON format using:
   # `arv get [uuid] --format json`.
-  def test_get_valid_object_json_format()
-    stored_value = __method__
+  def test_get_valid_object_json_format_specified()
+    stored_value = __method__.to_s
     uuid = create_arv_object_with_value(stored_value)
     out, err = capture_subprocess_io do
-      arv_get(uuid, '--format', 'json')
+      assert(arv_get_json(uuid))
     end
-    assert_empty(err)
-    refute_empty(out)
+    assert_empty(err, "Error text not expected: '#{err}'")
     arv_object = parse_json_arv_object(out)
     assert(has_field_with_value(arv_object, STORED_VALUE_FIELD_NAME, stored_value))
   end
 
   # Tests that a valid Arvados object can be retrieved in YAML format using:
   # `arv get [uuid] --format yaml`.
-  def test_get_valid_object_yaml_format()
-    stored_value = __method__
+  def test_get_valid_object_yaml_format_specified()
+    stored_value = __method__.to_s
     uuid = create_arv_object_with_value(stored_value)
     out, err = capture_subprocess_io do
-      arv_get(uuid, '--format', 'yaml')
+      assert(arv_get_yaml(uuid))
     end
-    assert_empty(err)
-    refute_empty(out)
+    assert_empty(err, "Error text not expected: '#{err}'")
     arv_object = parse_yaml_arv_object(out)
     assert(has_field_with_value(arv_object, STORED_VALUE_FIELD_NAME, stored_value))
   end
 
   # Tests that a subset of all fields of a valid Arvados object can be retrieved
   # using: `arv get [uuid] [fields...]`.
-  def test_get_valid_object_with_specific_valid_fields()
-    stored_value = __method__
+  def test_get_valid_object_with_valid_fields()
+    stored_value = __method__.to_s
     uuid = create_arv_object_with_value(stored_value)
     out, err = capture_subprocess_io do
-      arv_get(uuid, STORED_VALUE_FIELD_NAME, UUID_FIELD_NAME, "--format", "json")
+      assert(arv_get_json(uuid, STORED_VALUE_FIELD_NAME, UUID_FIELD_NAME))
     end
-    assert_empty(err)
-    refute_empty(out)
+    assert_empty(err, "Error text not expected: '#{err}'")
     arv_object = parse_json_arv_object(out)
     assert(has_field_with_value(arv_object, STORED_VALUE_FIELD_NAME, stored_value))
     assert(has_field_with_value(arv_object, UUID_FIELD_NAME, uuid))
@@ -74,14 +70,13 @@ class TestArvGet < Minitest::Test
   # Tests that the valid field is retrieved when both a valid and invalid field
   # are requested from a valid Arvados object, using:
   # `arv get [uuid] [fields...]`.
-  def test_get_valid_object_with_both_specific_valid_and_invalid_fields()
-    stored_value = __method__
+  def test_get_valid_object_with_both_valid_and_invalid_fields()
+    stored_value = __method__.to_s
     uuid = create_arv_object_with_value(stored_value)
     out, err = capture_subprocess_io do
-      arv_get(uuid, STORED_VALUE_FIELD_NAME, INVALID_FIELD_NAME, "--format", "json")
+      assert(arv_get_json(uuid, STORED_VALUE_FIELD_NAME, INVALID_FIELD_NAME))
     end
-    assert_empty(err)
-    refute_empty(out)
+    assert_empty(err, "Error text not expected: '#{err}'")
     arv_object = parse_json_arv_object(out)
     assert(has_field_with_value(arv_object, STORED_VALUE_FIELD_NAME, stored_value))
     refute(has_field_with_value(arv_object, INVALID_FIELD_NAME, stored_value))
@@ -89,65 +84,69 @@ class TestArvGet < Minitest::Test
 
   # Tests that no fields are retreived when no valid fields are requested from
   # a valid Arvados object, using: `arv get [uuid] [fields...]`.
-  def test_get_valid_object_with_no_specific_valid_fields()
-    stored_value = __method__
+  def test_get_valid_object_with_no_valid_fields()
+    stored_value = __method__.to_s
     uuid = create_arv_object_with_value(stored_value)
     out, err = capture_subprocess_io do
-      arv_get(uuid, INVALID_FIELD_NAME, "--format", "json")
+      assert(arv_get_json(uuid, INVALID_FIELD_NAME))
     end
-    assert_empty(err)
-    refute_empty(out)
+    assert_empty(err, "Error text not expected: '#{err}'")
     arv_object = parse_json_arv_object(out)
-    assert_equal(0, arv_object.fixnum)
-  end
-
-  # Tests that an valid Arvados object is not retrieved when specifying an
-  # invalid format: `arv get [uuid] --format invalid`.
-  def test_get_valid_object_invalid_format()
-    stored_value = __method__
-    uuid = create_arv_object_with_value(stored_value)
-    out, err = capture_subprocess_io do
-      arv_get(uuid, '--format', 'invalid')
-    end
-    refute_empty(err)
-    assert_empty(out)
+    assert_equal(0, arv_object.length)
   end
 
   # Tests that an invalid (non-existant) Arvados object is not retrieved using:
   # using: `arv get [non-existant-uuid]`.
   def test_get_invalid_object()
     out, err = capture_subprocess_io do
-      arv_get(NON_EXISTANT_OBJECT_UUID, "--format", "json")
+      refute(arv_get_json(NON_EXISTANT_OBJECT_UUID))
     end
-    refute_empty(err)
+    refute_empty(err, "Expected error feedback on request for invalid object")
     assert_empty(out)
   end
 
   # Tests that help text exists using: `arv get --help`.
   def test_help_exists()
     out, err = capture_subprocess_io do
-      arv_get("--help")
+      assert(arv_get_default("--help"), "Expected exit code 0: #{$?}")
     end
-    assert_empty(err)
-    refute_empty(out)
+    assert_empty(err, "Error text not expected: '#{err}'")
+    refute_empty(out, "Help text should be given")
   end
 
   protected
-  # Runs 'arv get <varargs>' with given arguments.
-  def arv_get(*args)
-    system(['./bin/arv', 'get'], *args)
+  # Runs 'arv get <varargs>' with given arguments. Returns whether the exit
+  # status was 0 (i.e. success). Use $? to attain more details on failure.
+  def arv_get_default(*args)
+    return system("arv", "get", *args)
+  end
+
+  # Runs 'arv --format json get <varargs>' with given arguments. Returns whether
+  # the exit status was 0 (i.e. success). Use $? to attain more details on
+  # failure.
+  def arv_get_json(*args)
+    return system("arv", "--format", "json", "get", *args)
+  end
+
+  # Runs 'arv --format yaml get <varargs>' with given arguments. Returns whether
+  # the exit status was 0 (i.e. success). Use $? to attain more details on
+  # failure.
+  def arv_get_yaml(*args)
+    return system("arv", "--format", "yaml", "get", *args)
   end
 
   # Creates an Arvados object that stores a given value. Returns the uuid of the
   # created object.
   def create_arv_object_with_value(value)
       out, err = capture_subprocess_io do
-        # Write (without redirect)
-        system(['./bin/arv', "tag add #{value} --object testing"])
+        if !system("arv", "tag", "add", "#{value}", "--object", "testing")
+          raise "Command failure running `arv tag` with arguments #{args}: #{$?}"
+        end
       end
-      if err.length > 0
+      if err.length > 0 || out.length == 0
         raise "Could not create Arvados object with given value"
       end
+      out = out.delete!("\n")
       return out
   end
 
@@ -160,8 +159,8 @@ class TestArvGet < Minitest::Test
       return parsed
     rescue JSON::ParserError => e
       raise "Invalid JSON representation of Arvados object.\n" \
-            "Parse error: #{e}\n" \
-            "JSON: #{arvObjectAsJson}\n"
+            "Parse error: '#{e}'\n" \
+            "JSON: '#{arvObjectAsJson}'\n"
     end
   end
 
@@ -174,7 +173,7 @@ class TestArvGet < Minitest::Test
       return parsed
     rescue
       raise "Invalid YAML representation of Arvados object.\n" \
-            "YAML: #{arvObjectAsYaml}\n"
+            "YAML: '#{arvObjectAsYaml}'\n"
     end
   end
 

commit 76bb593e5b16879a5efc85515cb47e179b31601f
Author: Colin Nolan <colin.nolan at sanger.ac.uk>
Date:   Tue Sep 22 10:29:42 2015 +0100

    7204: Added user documentation for `arv get` command.

diff --git a/doc/sdk/cli/subcommands.html.textile.liquid b/doc/sdk/cli/subcommands.html.textile.liquid
index 3184c09..80ed56a 100644
--- a/doc/sdk/cli/subcommands.html.textile.liquid
+++ b/doc/sdk/cli/subcommands.html.textile.liquid
@@ -21,6 +21,28 @@ Options:
 </pre>
 </notextile>
 
+h3(#arv-get). arv get
+
+ at arv get@ can be used to get a textual representation of Arvados objects from the command line. The output can be limited to a subset of the object's fields. This command can be used with only the knowledge of an object's UUID.
+
+<notextile>
+<pre>
+$ <code class="userinput">arv arv get --help</code>
+Usage: arv get [uuid] [fields...]
+Fetch the specified Arvados object, select the specified fields,
+and print a text representation (json or yaml, use --format).
+</pre>
+</notextile>
+*Note*: the 'format' flag is used by @arv@ (not @arv get@), as detailed on the "arv CLI overview page":{{site.baseurl}}/sdk/cli/index.html.
+
+This command can be used instead of the previously required:
+
+<notextile>
+<pre>
+$ <code class="userinput">EDITOR=cat arv edit [uuid]</code>
+</pre>
+</notextile>
+
 h3(#arv-edit). arv edit
 
 @arv edit@ can be used to edit Arvados objects from the command line. Arv edit opens up the editor of your choice (set the EDITOR environment variable) with the json or yaml description of the object. Saving the file will update the Arvados object on the API server, if it passes validation.

commit 1b5e6506170075e5c01dda7489d814dd4c3f7774
Author: Colin Nolan <colin.nolan at sanger.ac.uk>
Date:   Mon Sep 21 12:52:26 2015 +0100

    7204: Fixed bugs in tests for `arg get`.

diff --git a/sdk/cli/test/test_arv-get.rb b/sdk/cli/test/test_arv-get.rb
index 76b110a..d0b569c 100644
--- a/sdk/cli/test/test_arv-get.rb
+++ b/sdk/cli/test/test_arv-get.rb
@@ -5,7 +5,7 @@ require 'yaml'
 # Black box tests for 'arv get' command.
 class TestArvGet < Minitest::Test
   # UUID for an Arvados object that does not exist
-  NON_EXISTANT_OBJECT_UUID = "qr1hi-tpzed-p8yk1lihjsgwew0"
+  NON_EXISTANT_OBJECT_UUID = "qr1hi-tpzed-p9yk1lihjsgwew0"
   # Name of field of Arvados object that can store any (textual) value
   STORED_VALUE_FIELD_NAME = "name"
   # Name of UUID field of Arvados object
@@ -13,6 +13,21 @@ class TestArvGet < Minitest::Test
   # Name of an invalid field of Arvados object
   INVALID_FIELD_NAME = "invalid"
 
+  # Tests that a valid Arvados object can be retrieved in a supported format
+  # using: `arv get [uuid]`. Given all other `arv foo` commands return JSON
+  # when no format is specified, JSON should be expected in this case.
+  def test_get_valid_object_no_format()
+    stored_value = __method__
+    uuid = create_arv_object_with_value(stored_value)
+    out, err = capture_subprocess_io do
+      arv_get(uuid)
+    end
+    assert_empty(err)
+    refute_empty(out)
+    arv_object = parse_json_arv_object(out)
+    assert(has_field_with_value(arv_object, STORED_VALUE_FIELD_NAME, stored_value))
+  end
+
   # Tests that a valid Arvados object can be retrieved in JSON format using:
   # `arv get [uuid] --format json`.
   def test_get_valid_object_json_format()
@@ -22,6 +37,7 @@ class TestArvGet < Minitest::Test
       arv_get(uuid, '--format', 'json')
     end
     assert_empty(err)
+    refute_empty(out)
     arv_object = parse_json_arv_object(out)
     assert(has_field_with_value(arv_object, STORED_VALUE_FIELD_NAME, stored_value))
   end
@@ -35,24 +51,11 @@ class TestArvGet < Minitest::Test
       arv_get(uuid, '--format', 'yaml')
     end
     assert_empty(err)
+    refute_empty(out)
     arv_object = parse_yaml_arv_object(out)
     assert(has_field_with_value(arv_object, STORED_VALUE_FIELD_NAME, stored_value))
   end
 
-  # Tests that a valid Arvados object can be retrieved in a supported format
-  # using: `arv get [uuid]`. Given all other `arv foo` commands return JSON
-  # when no format is specified, JSON should be expected in this case.
-  def test_get_valid_object_no_format()
-    stored_value = __method__
-    uuid = create_arv_object_with_value(stored_value)
-    out, err = capture_subprocess_io do
-      arv_get(uuid)
-    end
-    assert_empty(err)
-    arv_object = parse_json_arv_object(out)
-    assert(has_field_with_value(arv_object, STORED_VALUE_FIELD_NAME, stored_value))
-  end
-
   # Tests that a subset of all fields of a valid Arvados object can be retrieved
   # using: `arv get [uuid] [fields...]`.
   def test_get_valid_object_with_specific_valid_fields()
@@ -62,6 +65,7 @@ class TestArvGet < Minitest::Test
       arv_get(uuid, STORED_VALUE_FIELD_NAME, UUID_FIELD_NAME, "--format", "json")
     end
     assert_empty(err)
+    refute_empty(out)
     arv_object = parse_json_arv_object(out)
     assert(has_field_with_value(arv_object, STORED_VALUE_FIELD_NAME, stored_value))
     assert(has_field_with_value(arv_object, UUID_FIELD_NAME, uuid))
@@ -77,6 +81,7 @@ class TestArvGet < Minitest::Test
       arv_get(uuid, STORED_VALUE_FIELD_NAME, INVALID_FIELD_NAME, "--format", "json")
     end
     assert_empty(err)
+    refute_empty(out)
     arv_object = parse_json_arv_object(out)
     assert(has_field_with_value(arv_object, STORED_VALUE_FIELD_NAME, stored_value))
     refute(has_field_with_value(arv_object, INVALID_FIELD_NAME, stored_value))
@@ -91,6 +96,7 @@ class TestArvGet < Minitest::Test
       arv_get(uuid, INVALID_FIELD_NAME, "--format", "json")
     end
     assert_empty(err)
+    refute_empty(out)
     arv_object = parse_json_arv_object(out)
     assert_equal(0, arv_object.fixnum)
   end
@@ -117,10 +123,19 @@ class TestArvGet < Minitest::Test
     assert_empty(out)
   end
 
+  # Tests that help text exists using: `arv get --help`.
+  def test_help_exists()
+    out, err = capture_subprocess_io do
+      arv_get("--help")
+    end
+    assert_empty(err)
+    refute_empty(out)
+  end
+
   protected
   # Runs 'arv get <varargs>' with given arguments.
   def arv_get(*args)
-    system(['./bin/arv', 'arv get'], *args)
+    system(['./bin/arv', 'get'], *args)
   end
 
   # Creates an Arvados object that stores a given value. Returns the uuid of the
@@ -128,7 +143,7 @@ class TestArvGet < Minitest::Test
   def create_arv_object_with_value(value)
       out, err = capture_subprocess_io do
         # Write (without redirect)
-        system(['./bin/arv', "arv tag add #{value} --object testing"])
+        system(['./bin/arv', "tag add #{value} --object testing"])
       end
       if err.length > 0
         raise "Could not create Arvados object with given value"
@@ -144,7 +159,9 @@ class TestArvGet < Minitest::Test
       assert(parsed.instance_of?(Hash))
       return parsed
     rescue JSON::ParserError => e
-      raise "Invalid JSON representation of Arvados object"
+      raise "Invalid JSON representation of Arvados object.\n" \
+            "Parse error: #{e}\n" \
+            "JSON: #{arvObjectAsJson}\n"
     end
   end
 
@@ -156,7 +173,8 @@ class TestArvGet < Minitest::Test
       assert(parsed.instance_of?(Hash))
       return parsed
     rescue
-      raise "Invalid YAML representation of Arvados object"
+      raise "Invalid YAML representation of Arvados object.\n" \
+            "YAML: #{arvObjectAsYaml}\n"
     end
   end
 

commit 59ee5d1b20c9d4b06c194b33b781d353d8e0ba3c
Author: Colin Nolan <colin.nolan at sanger.ac.uk>
Date:   Mon Sep 21 11:23:45 2015 +0100

    7204: Completed additional tests for `arg get`.

diff --git a/sdk/cli/test/test_arv-get.rb b/sdk/cli/test/test_arv-get.rb
index c9a5abe..c0f9146 100644
--- a/sdk/cli/test/test_arv-get.rb
+++ b/sdk/cli/test/test_arv-get.rb
@@ -44,6 +44,16 @@ class TestArvGet < Minitest::Test
         does_arv_object_as_json_use_value(out, stored_value))
   end
 
+  # TODO: Add tests for selecting specific fields
+  def test_get_valid_object_with_specific_valid_fields()
+    # TODO
+  end
+
+  # TODO: Add tests for selecting specific fields
+  def test_get_valid_object_with_both_specific_valid_and_invalid_fields()
+    # TODO
+  end
+
   # Tests that an valid Arvados object is not retrieved when specifying an
   # invalid format: `arv get [uuid] --format invalid`.
   def test_get_object_invalid_format()
@@ -97,6 +107,11 @@ class TestArvGet < Minitest::Test
     assert_empty(out)
   end
 
+  # TODO: Test what happens when valid object but invalid fields
+  def test_get_valid_object_with_specific_invalid_fields()
+    # TODO
+  end
+
   protected
   # Runs 'arv get <varargs>' with given arguments.
   def arv_get(*args)

commit 9e845fe4a5ff18f66c3850b25aae5f77680ac7cd
Author: Colin Nolan <colin.nolan at sanger.ac.uk>
Date:   Fri Sep 18 18:54:49 2015 +0100

    7204: Fixed bugs in `arg get` tests.7204: Fixed bugs in `arg get` tests.7204: Fixed bugs in `arg get` tests.7204: Fixed bugs in `arg get` tests.7204: Fixed bugs in `arg get` tests.7204: Fixed bugs in `arg get` tests.7204: Fixed bugs in `arg get` tests.

diff --git a/sdk/cli/test/test_arv-get.rb b/sdk/cli/test/test_arv-get.rb
index ccc1e16..c9a5abe 100644
--- a/sdk/cli/test/test_arv-get.rb
+++ b/sdk/cli/test/test_arv-get.rb
@@ -11,7 +11,7 @@ class TestArvGet < Minitest::Test
   # `arv get [uuid] --format json`.
   def test_get_valid_object_json_format()
     stored_value = __method__
-    uuid = create_arv_object_containing_value(stored_value)
+    uuid = create_arv_object_with_value(stored_value)
     out, err = capture_subprocess_io do
       arv_get(uuid, '--format', 'json')
     end
@@ -23,7 +23,7 @@ class TestArvGet < Minitest::Test
   # `arv get [uuid] --format yaml`.
   def test_get_valid_object_yaml_format()
     stored_value = __method__
-    uuid = create_arv_object_containing_value(stored_value)
+    uuid = create_arv_object_with_value(stored_value)
     out, err = capture_subprocess_io do
       arv_get(uuid, '--format', 'yaml')
     end
@@ -35,7 +35,7 @@ class TestArvGet < Minitest::Test
   # using: `arv get [uuid]`.
   def test_get_valid_object_no_format()
     stored_value = __method__
-    uuid = create_arv_object_containing_value(stored_value)
+    uuid = create_arv_object_with_value(stored_value)
     out, err = capture_subprocess_io do
       arv_get(uuid)
     end
@@ -48,7 +48,7 @@ class TestArvGet < Minitest::Test
   # invalid format: `arv get [uuid] --format invalid`.
   def test_get_object_invalid_format()
     stored_value = __method__
-    uuid = create_arv_object_containing_value(stored_value)
+    uuid = create_arv_object_with_value(stored_value)
     out, err = capture_subprocess_io do
       arv_get(uuid, '--format', 'invalid')
     end
@@ -119,20 +119,29 @@ class TestArvGet < Minitest::Test
   # Checks whether the Arvados object, represented in JSON format, uses the
   # given value.
   def does_arv_object_as_json_use_value(obj, value)
-    parsed = JSON.parse(obj)
-    return does_arv_object_as_object_use_value(parsed, value)
+    begin
+      parsed = JSON.parse(obj)
+      return does_arv_object_as_ruby_object_use_value(parsed, value)
+    rescue JSON::ParserError => e
+      raise "Invalid JSON representation of Arvados object"
+    end
   end
 
   # Checks whether the Arvados object, represented in YAML format, uses the
   # given value.
   def does_arv_object_as_yaml_use_value(obj, value)
-    parsed = YAML.load(obj)
-    return does_arv_object_as_object_use_value(parsed, value)
+    begin
+      parsed = YAML.load(obj)
+      return does_arv_object_as_ruby_object_use_value(parsed, value)
+    rescue
+      raise "Invalid YAML representation of Arvados object"
+    end
   end
 
   # Checks whether the Arvados object, represented as a Ruby object, uses the
   # given value.
-  def does_arv_object_as_object_use_value(obj, value)
+  def does_arv_object_as_ruby_object_use_value(obj, value)
+    assert(parsed.instance_of?(Hash))
     stored_value = obj["name"]
     return (value == stored_value)
   end

commit 1a4b37d333d312a97c7979b1203c6246a28e601b
Author: Colin Nolan <colin.nolan at sanger.ac.uk>
Date:   Fri Sep 18 12:04:58 2015 +0100

    7204: Minor refactoring of methods supporting `arv get` test cases.

diff --git a/sdk/cli/test/test_arv-get.rb b/sdk/cli/test/test_arv-get.rb
index a1d49a6..ccc1e16 100644
--- a/sdk/cli/test/test_arv-get.rb
+++ b/sdk/cli/test/test_arv-get.rb
@@ -116,19 +116,24 @@ class TestArvGet < Minitest::Test
       return out
   end
 
-  # Checks whether the Arvados object, represented in JSON format, with the
-  # given uuid, uses the given value.
+  # Checks whether the Arvados object, represented in JSON format, uses the
+  # given value.
   def does_arv_object_as_json_use_value(obj, value)
     parsed = JSON.parse(obj)
-    stored_value = parsed["name"]
-    return (value == stored_value)
+    return does_arv_object_as_object_use_value(parsed, value)
   end
 
-  # Checks whether the Arvados object, represented in YAML format, with the
-  # given uuid, uses the given value.
+  # Checks whether the Arvados object, represented in YAML format, uses the
+  # given value.
   def does_arv_object_as_yaml_use_value(obj, value)
     parsed = YAML.load(obj)
-    stored_value = parsed["name"]
+    return does_arv_object_as_object_use_value(parsed, value)
+  end
+
+  # Checks whether the Arvados object, represented as a Ruby object, uses the
+  # given value.
+  def does_arv_object_as_object_use_value(obj, value)
+    stored_value = obj["name"]
     return (value == stored_value)
   end
 end

commit fd0bb03ede4bf503fc599f9bac468adb620b2142
Author: Colin Nolan <colin.nolan at sanger.ac.uk>
Date:   Fri Sep 18 11:57:13 2015 +0100

    7204: Completed supporting methods for `arv get` test cases.

diff --git a/sdk/cli/test/test_arv-get.rb b/sdk/cli/test/test_arv-get.rb
index 2264bfc..a1d49a6 100644
--- a/sdk/cli/test/test_arv-get.rb
+++ b/sdk/cli/test/test_arv-get.rb
@@ -1,4 +1,6 @@
 require 'minitest/autorun'
+require 'json'
+require 'yaml'
 
 # Black box tests for 'arv get' command.
 class TestArvGet < Minitest::Test
@@ -14,7 +16,7 @@ class TestArvGet < Minitest::Test
       arv_get(uuid, '--format', 'json')
     end
     assert_empty(err)
-    assert(does_arv_object_as_json_use_value(uuid, stored_value))
+    assert(does_arv_object_as_json_use_value(out, stored_value))
   end
 
   # Tests that a valid Arvados object can be retrieved in YAML format using:
@@ -26,7 +28,7 @@ class TestArvGet < Minitest::Test
       arv_get(uuid, '--format', 'yaml')
     end
     assert_empty(err)
-    assert(does_arv_object_as_yaml_use_value(uuid, stored_value))
+    assert(does_arv_object_as_yaml_use_value(out, stored_value))
   end
 
   # Tests that a valid Arvados object can be retrieved in a supported format
@@ -38,8 +40,8 @@ class TestArvGet < Minitest::Test
       arv_get(uuid)
     end
     assert_empty(err)
-    assert(does_arv_object_as_yaml_use_value(uuid, stored_value) ||
-        does_arv_object_as_json_use_value(uuid, stored_value))
+    assert(does_arv_object_as_yaml_use_value(out, stored_value) ||
+        does_arv_object_as_json_use_value(out, stored_value))
   end
 
   # Tests that an valid Arvados object is not retrieved when specifying an
@@ -98,31 +100,35 @@ class TestArvGet < Minitest::Test
   protected
   # Runs 'arv get <varargs>' with given arguments.
   def arv_get(*args)
-    system ['./bin/arv', 'arv get'], *args
+    system(['./bin/arv', 'arv get'], *args)
   end
 
-  # Creates an Arvados object that stores a given value.
-  # TODO: Must return uuid
+  # Creates an Arvados object that stores a given value. Returns the uuid of the
+  # created object.
   def create_arv_object_with_value(value)
       out, err = capture_subprocess_io do
         # Write (without redirect)
-        system ['./bin/arv', 'arv create log'], *args
+        system(['./bin/arv', "arv tag add #{value} --object testing"])
       end
       if err.length > 0
         raise "Could not create Arvados object with given value"
       end
-#    system ['./bin/arv', 'arv user create'], *args
+      return out
   end
 
   # Checks whether the Arvados object, represented in JSON format, with the
   # given uuid, uses the given value.
-  def does_arv_object_as_json_use_value(uuid, value)
-    # TODO
+  def does_arv_object_as_json_use_value(obj, value)
+    parsed = JSON.parse(obj)
+    stored_value = parsed["name"]
+    return (value == stored_value)
   end
 
   # Checks whether the Arvados object, represented in YAML format, with the
   # given uuid, uses the given value.
-  def does_arv_object_as_yaml_use_value(uuid, value)
-    # TODO
+  def does_arv_object_as_yaml_use_value(obj, value)
+    parsed = YAML.load(obj)
+    stored_value = parsed["name"]
+    return (value == stored_value)
   end
 end

commit 044804a54376e69baccb23a241f7e7bffd7b529b
Author: Colin Nolan <colin.nolan at sanger.ac.uk>
Date:   Fri Sep 18 10:11:58 2015 +0100

    7204: Created black box test cases for `arv get` command.

diff --git a/sdk/cli/test/test_arv-get.rb b/sdk/cli/test/test_arv-get.rb
index 869ea6d..2264bfc 100644
--- a/sdk/cli/test/test_arv-get.rb
+++ b/sdk/cli/test/test_arv-get.rb
@@ -1,19 +1,98 @@
 require 'minitest/autorun'
 
-# Test for 'arv get' command.
+# Black box tests for 'arv get' command.
 class TestArvGet < Minitest::Test
-  # Test setup.
-  def setup
-    # No setup required.
+  # UUID for an Arvados object that does not exist
+  NON_EXISTANT_OBJECT_UUID = "qr1hi-tpzed-p8yk1lihjsgwew0"
+
+  # Tests that a valid Arvados object can be retrieved in JSON format using:
+  # `arv get [uuid] --format json`.
+  def test_get_valid_object_json_format()
+    stored_value = __method__
+    uuid = create_arv_object_containing_value(stored_value)
+    out, err = capture_subprocess_io do
+      arv_get(uuid, '--format', 'json')
+    end
+    assert_empty(err)
+    assert(does_arv_object_as_json_use_value(uuid, stored_value))
+  end
+
+  # Tests that a valid Arvados object can be retrieved in YAML format using:
+  # `arv get [uuid] --format yaml`.
+  def test_get_valid_object_yaml_format()
+    stored_value = __method__
+    uuid = create_arv_object_containing_value(stored_value)
+    out, err = capture_subprocess_io do
+      arv_get(uuid, '--format', 'yaml')
+    end
+    assert_empty(err)
+    assert(does_arv_object_as_yaml_use_value(uuid, stored_value))
+  end
+
+  # Tests that a valid Arvados object can be retrieved in a supported format
+  # using: `arv get [uuid]`.
+  def test_get_valid_object_no_format()
+    stored_value = __method__
+    uuid = create_arv_object_containing_value(stored_value)
+    out, err = capture_subprocess_io do
+      arv_get(uuid)
+    end
+    assert_empty(err)
+    assert(does_arv_object_as_yaml_use_value(uuid, stored_value) ||
+        does_arv_object_as_json_use_value(uuid, stored_value))
+  end
+
+  # Tests that an valid Arvados object is not retrieved when specifying an
+  # invalid format: `arv get [uuid] --format invalid`.
+  def test_get_object_invalid_format()
+    stored_value = __method__
+    uuid = create_arv_object_containing_value(stored_value)
+    out, err = capture_subprocess_io do
+      arv_get(uuid, '--format', 'invalid')
+    end
+    refute_empty(err)
+    assert_empty(out)
+  end
+
+  # Tests that an invalid (non-existant) Arvados object is not retrieved using:
+  # using: `arv get [non-existant-uuid] --format json`.
+  def test_get_invalid_object_json_format()
+    out, err = capture_subprocess_io do
+      arv_get(NON_EXISTANT_OBJECT_UUID, '--format', 'json')
+    end
+    refute_empty(err)
+    assert_empty(out)
+  end
+
+  # Tests that an invalid (non-existant) Arvados object is not retrieved using:
+  # using: `arv get [non-existant-uuid] --format yaml`.
+  def test_get_invalid_object_yaml_format()
+    out, err = capture_subprocess_io do
+      arv_get(NON_EXISTANT_OBJECT_UUID, '--format', 'yaml')
+    end
+    refute_empty(err)
+    assert_empty(out)
   end
 
-  # Tests something... TODO.
-  def test_get_TODO
+  # Tests that an invalid (non-existant) Arvados object is not retrieved using:
+  # using: `arv get [non-existant-uuid]`.
+  def test_get_invalid_object_no_format()
     out, err = capture_subprocess_io do
-      arv_get
+      arv_get(NON_EXISTANT_OBJECT_UUID)
     end
+    refute_empty(err)
+    assert_empty(out)
+  end
 
-    assert_empty err
+  # Tests that an invalid (non-existant) Arvados object is not retrieved when
+  # specifying an invalid format:
+  # `arv get [non-existant-uuid] --format invalid`.
+  def test_get_object_invalid_format()
+    out, err = capture_subprocess_io do
+      arv_get(NON_EXISTANT_OBJECT_UUID, '--format', 'invalid')
+    end
+    refute_empty(err)
+    assert_empty(out)
   end
 
   protected
@@ -21,4 +100,29 @@ class TestArvGet < Minitest::Test
   def arv_get(*args)
     system ['./bin/arv', 'arv get'], *args
   end
+
+  # Creates an Arvados object that stores a given value.
+  # TODO: Must return uuid
+  def create_arv_object_with_value(value)
+      out, err = capture_subprocess_io do
+        # Write (without redirect)
+        system ['./bin/arv', 'arv create log'], *args
+      end
+      if err.length > 0
+        raise "Could not create Arvados object with given value"
+      end
+#    system ['./bin/arv', 'arv user create'], *args
+  end
+
+  # Checks whether the Arvados object, represented in JSON format, with the
+  # given uuid, uses the given value.
+  def does_arv_object_as_json_use_value(uuid, value)
+    # TODO
+  end
+
+  # Checks whether the Arvados object, represented in YAML format, with the
+  # given uuid, uses the given value.
+  def does_arv_object_as_yaml_use_value(uuid, value)
+    # TODO
+  end
 end

commit ba0d6a92c642ca86dae5ab807b3ad7fe04e335d2
Author: Colin Nolan <colin.nolan at sanger.ac.uk>
Date:   Thu Sep 17 11:45:43 2015 +0100

    7204: Setup for testing new `arg get` command.

diff --git a/sdk/cli/test/test_arv-get.rb b/sdk/cli/test/test_arv-get.rb
index 5e58014..869ea6d 100644
--- a/sdk/cli/test/test_arv-get.rb
+++ b/sdk/cli/test/test_arv-get.rb
@@ -1,251 +1,24 @@
 require 'minitest/autorun'
-require 'digest/md5'
 
+# Test for 'arv get' command.
 class TestArvGet < Minitest::Test
+  # Test setup.
   def setup
-    begin
-      Dir.mkdir './tmp'
-    rescue Errno::EEXIST
-    end
-    @@foo_manifest_locator ||= `echo -n foo | ./bin/arv-put --filename foo --no-progress -`.strip
-    @@baz_locator ||= `echo -n baz | ./bin/arv-put --as-raw --no-progress -`.strip
-    @@multilevel_manifest_locator ||= `echo ./foo/bar #{@@baz_locator} 0:3:baz | ./bin/arv-put --as-raw --no-progress -`.strip
-  end
-
-  def test_no_args
-    out, err = capture_subprocess_io do
-      assert_arv_get false
-    end
-    assert_equal '', out
-    assert_match /^usage:/, err
-  end
-
-  def test_help
-    out, err = capture_subprocess_io do
-      assert_arv_get '-h'
-    end
-    $stderr.write err
-    assert_equal '', err
-    assert_match /^usage:/, out
-  end
-
-  def test_file_to_dev_stdout
-    test_file_to_stdout('/dev/stdout')
-  end
-
-  def test_file_to_stdout(specify_stdout_as='-')
-    out, err = capture_subprocess_io do
-      assert_arv_get @@foo_manifest_locator + '/foo', specify_stdout_as
-    end
-    assert_equal '', err
-    assert_equal 'foo', out
-  end
-
-  def test_file_to_file
-    remove_tmp_foo
-    out, err = capture_subprocess_io do
-      assert_arv_get @@foo_manifest_locator + '/foo', 'tmp/foo'
-    end
-    assert_equal '', err
-    assert_equal '', out
-    assert_equal 'foo', IO.read('tmp/foo')
-  end
-
-  def test_file_to_file_no_overwrite_file
-    File.open './tmp/foo', 'wb' do |f|
-      f.write 'baz'
-    end
-    out, err = capture_subprocess_io do
-      assert_arv_get false, @@foo_manifest_locator + '/foo', 'tmp/foo'
-    end
-    assert_match /Local file tmp\/foo already exists/, err
-    assert_equal '', out
-    assert_equal 'baz', IO.read('tmp/foo')
-  end
-
-  def test_file_to_file_no_overwrite_file_in_dir
-    File.open './tmp/foo', 'wb' do |f|
-      f.write 'baz'
-    end
-    out, err = capture_subprocess_io do
-      assert_arv_get false, @@foo_manifest_locator + '/', 'tmp/'
-    end
-    assert_match /Local file tmp\/foo already exists/, err
-    assert_equal '', out
-    assert_equal 'baz', IO.read('tmp/foo')
-  end
-
-  def test_file_to_file_force_overwrite
-    File.open './tmp/foo', 'wb' do |f|
-      f.write 'baz'
-    end
-    assert_equal 'baz', IO.read('tmp/foo')
-    out, err = capture_subprocess_io do
-      assert_arv_get '-f', @@foo_manifest_locator + '/', 'tmp/'
-    end
-    assert_match '', err
-    assert_equal '', out
-    assert_equal 'foo', IO.read('tmp/foo')
-  end
-
-  def test_file_to_file_skip_existing
-    File.open './tmp/foo', 'wb' do |f|
-      f.write 'baz'
-    end
-    assert_equal 'baz', IO.read('tmp/foo')
-    out, err = capture_subprocess_io do
-      assert_arv_get '--skip-existing', @@foo_manifest_locator + '/', 'tmp/'
-    end
-    assert_match '', err
-    assert_equal '', out
-    assert_equal 'baz', IO.read('tmp/foo')
-  end
-
-  def test_file_to_dir
-    remove_tmp_foo
-    out, err = capture_subprocess_io do
-      assert_arv_get @@foo_manifest_locator + '/foo', 'tmp/'
-    end
-    assert_equal '', err
-    assert_equal '', out
-    assert_equal 'foo', IO.read('tmp/foo')
-  end
-
-  def test_dir_to_file
-    out, err = capture_subprocess_io do
-      assert_arv_get false, @@foo_manifest_locator + '/', 'tmp/foo'
-    end
-    assert_equal '', out
-    assert_match /^usage:/, err
-  end
-
-  def test_dir_to_empty_string
-    out, err = capture_subprocess_io do
-      assert_arv_get false, @@foo_manifest_locator + '/', ''
-    end
-    assert_equal '', out
-    assert_match /^usage:/, err
+    # No setup required.
   end
 
-  def test_nonexistent_block
+  # Tests something... TODO.
+  def test_get_TODO
     out, err = capture_subprocess_io do
-      assert_arv_get false, 'e796ab2294f3e48ec709ffa8d6daf58c'
+      arv_get
     end
-    assert_equal '', out
-    assert_match /Error:/, err
-  end
 
-  def test_nonexistent_manifest
-    out, err = capture_subprocess_io do
-      assert_arv_get false, 'acbd18db4cc2f85cedef654fccc4a4d8/', 'tmp/'
-    end
-    assert_equal '', out
-    assert_match /Error:/, err
-  end
-
-  def test_manifest_root_to_dir
-    remove_tmp_foo
-    out, err = capture_subprocess_io do
-      assert_arv_get '-r', @@foo_manifest_locator + '/', 'tmp/'
-    end
-    assert_equal '', err
-    assert_equal '', out
-    assert_equal 'foo', IO.read('tmp/foo')
-  end
-
-  def test_manifest_root_to_dir_noslash
-    remove_tmp_foo
-    out, err = capture_subprocess_io do
-      assert_arv_get '-r', @@foo_manifest_locator + '/', 'tmp'
-    end
-    assert_equal '', err
-    assert_equal '', out
-    assert_equal 'foo', IO.read('tmp/foo')
-  end
-
-  def test_display_md5sum
-    remove_tmp_foo
-    out, err = capture_subprocess_io do
-      assert_arv_get '-r', '--md5sum', @@foo_manifest_locator + '/', 'tmp/'
-    end
-    assert_equal "#{Digest::MD5.hexdigest('foo')}  ./foo\n", err
-    assert_equal '', out
-    assert_equal 'foo', IO.read('tmp/foo')
-  end
-
-  def test_md5sum_nowrite
-    remove_tmp_foo
-    out, err = capture_subprocess_io do
-      assert_arv_get '-n', '--md5sum', @@foo_manifest_locator + '/', 'tmp/'
-    end
-    assert_equal "#{Digest::MD5.hexdigest('foo')}  ./foo\n", err
-    assert_equal '', out
-    assert_equal false, File.exists?('tmp/foo')
-  end
-
-  def test_sha1_nowrite
-    remove_tmp_foo
-    out, err = capture_subprocess_io do
-      assert_arv_get '-n', '-r', '--hash', 'sha1', @@foo_manifest_locator+'/', 'tmp/'
-    end
-    assert_equal "#{Digest::SHA1.hexdigest('foo')}  ./foo\n", err
-    assert_equal '', out
-    assert_equal false, File.exists?('tmp/foo')
-  end
-
-  def test_block_to_file
-    remove_tmp_foo
-    out, err = capture_subprocess_io do
-      assert_arv_get @@foo_manifest_locator, 'tmp/foo'
-    end
-    assert_equal '', err
-    assert_equal '', out
-
-    digest = Digest::MD5.hexdigest('foo')
-    !(IO.read('tmp/foo')).gsub!( /^(. #{digest}+3)(.*)( 0:3:foo)$/).nil?
-  end
-
-  def test_create_directory_tree
-    `rm -rf ./tmp/arv-get-test/`
-    Dir.mkdir './tmp/arv-get-test'
-    out, err = capture_subprocess_io do
-      assert_arv_get @@multilevel_manifest_locator + '/', 'tmp/arv-get-test/'
-    end
-    assert_equal '', err
-    assert_equal '', out
-    assert_equal 'baz', IO.read('tmp/arv-get-test/foo/bar/baz')
-  end
-
-  def test_create_partial_directory_tree
-    `rm -rf ./tmp/arv-get-test/`
-    Dir.mkdir './tmp/arv-get-test'
-    out, err = capture_subprocess_io do
-      assert_arv_get(@@multilevel_manifest_locator + '/foo/',
-                     'tmp/arv-get-test/')
-    end
-    assert_equal '', err
-    assert_equal '', out
-    assert_equal 'baz', IO.read('tmp/arv-get-test/bar/baz')
+    assert_empty err
   end
 
   protected
-  def assert_arv_get(*args)
-    expect = case args.first
-             when true, false
-               args.shift
-             else
-               true
-             end
-    assert_equal(expect,
-                 system(['./bin/arv-get', 'arv-get'], *args),
-                 "`arv-get #{args.join ' '}` " +
-                 "should exit #{if expect then 0 else 'non-zero' end}")
-  end
-
-  def remove_tmp_foo
-    begin
-      File.unlink('tmp/foo')
-    rescue Errno::ENOENT
-    end
+  # Runs 'arv get <varargs>' with given arguments.
+  def arv_get(*args)
+    system ['./bin/arv', 'arv get'], *args
   end
 end
diff --git a/sdk/cli/test/test_arv-get.rb b/sdk/cli/test/test_arv-keep-get.rb
similarity index 99%
copy from sdk/cli/test/test_arv-get.rb
copy to sdk/cli/test/test_arv-keep-get.rb
index 5e58014..0e578b8 100644
--- a/sdk/cli/test/test_arv-get.rb
+++ b/sdk/cli/test/test_arv-keep-get.rb
@@ -1,7 +1,7 @@
 require 'minitest/autorun'
 require 'digest/md5'
 
-class TestArvGet < Minitest::Test
+class TestArvKeepGet < Minitest::Test
   def setup
     begin
       Dir.mkdir './tmp'
diff --git a/sdk/cli/test/test_arv-put.rb b/sdk/cli/test/test_arv-keep-put.rb
similarity index 99%
rename from sdk/cli/test/test_arv-put.rb
rename to sdk/cli/test/test_arv-keep-put.rb
index 2f20e18..fefbc27 100644
--- a/sdk/cli/test/test_arv-put.rb
+++ b/sdk/cli/test/test_arv-keep-put.rb
@@ -1,7 +1,7 @@
 require 'minitest/autorun'
 require 'digest/md5'
 
-class TestArvPut < Minitest::Test
+class TestArvKeepPut < Minitest::Test
   def setup
     begin Dir.mkdir './tmp' rescue Errno::EEXIST end
     begin Dir.mkdir './tmp/empty_dir' rescue Errno::EEXIST end

commit be9b62b5186bd9aa961f08f66bc104200acf760a
Merge: 489caef 5ba12c5
Author: Joshua Randall <joshua.randall at sanger.ac.uk>
Date:   Mon Sep 7 20:05:14 2015 +0100

    Merge branch 'fix/7205-arv-edit-tty-check' into feature/arv-view


commit 489caef97d5185d91e7441980125480f98428c79
Author: Joshua Randall <joshua.randall at sanger.ac.uk>
Date:   Mon Sep 7 20:04:30 2015 +0100

    Adds an abort if global_opts[:format] is not recognized

diff --git a/sdk/cli/bin/arv b/sdk/cli/bin/arv
index caee76c..bddad98 100755
--- a/sdk/cli/bin/arv
+++ b/sdk/cli/bin/arv
@@ -185,6 +185,8 @@ def edit_and_commit_object initial_obj, tmp_stem, global_opts, &block
                    Oj.load(newcontent)
                  when 'yaml'
                    YAML.load(newcontent)
+                 else
+                   abort "Unrecognized format #{global_opts[:format]}"
                  end
 
         yield newobj

commit 80572f8164b46079617f0248b1372cf860ca9957
Author: Joshua Randall <joshua.randall at sanger.ac.uk>
Date:   Mon Sep 7 19:57:39 2015 +0100

    Makes bin_path local

diff --git a/sdk/cli/bin/arv b/sdk/cli/bin/arv
index f70f4d0..caee76c 100755
--- a/sdk/cli/bin/arv
+++ b/sdk/cli/bin/arv
@@ -88,11 +88,11 @@ end
 subcommands = %w(copy create edit get keep pipeline run tag ws)
 
 def exec_bin bin, opts
-  @bin_path = `which #{bin}`.strip
-  if @bin_path.empty?
+  bin_path = `which #{bin}`.strip
+  if bin_path.empty?
     raise "#{bin}: command not found"
   end
-  exec @bin_path, *opts
+  exec bin_path, *opts
 end
 
 def check_subcommands client, arvados, subcommand, global_opts, remaining_opts

commit 89e2ddbacad459856fc15f56bfa2b5c036b090a1
Author: Joshua Randall <joshua.randall at sanger.ac.uk>
Date:   Mon Sep 7 15:47:16 2015 +0100

    Changes new feature name to `arv get`

diff --git a/sdk/cli/bin/arv b/sdk/cli/bin/arv
index 252d267..f70f4d0 100755
--- a/sdk/cli/bin/arv
+++ b/sdk/cli/bin/arv
@@ -85,7 +85,7 @@ def init_config
 end
 
 
-subcommands = %w(copy create edit keep pipeline run tag view ws)
+subcommands = %w(copy create edit get keep pipeline run tag ws)
 
 def exec_bin bin, opts
   @bin_path = `which #{bin}`.strip
@@ -101,8 +101,8 @@ def check_subcommands client, arvados, subcommand, global_opts, remaining_opts
     arv_create client, arvados, global_opts, remaining_opts
   when 'edit'
     arv_edit client, arvados, global_opts, remaining_opts
-  when 'view'
-    arv_view client, arvados, global_opts, remaining_opts
+  when 'get'
+    arv_get client, arvados, global_opts, remaining_opts
   when 'copy', 'tag', 'ws', 'run'
     exec_bin "arv-#{subcommand}", remaining_opts
   when 'keep'
@@ -348,11 +348,11 @@ def arv_edit client, arvados, global_opts, remaining_opts
   exit 0
 end
 
-def arv_view client, arvados, global_opts, remaining_opts
+def arv_get client, arvados, global_opts, remaining_opts
   uuid = remaining_opts.shift
   if uuid.nil? or uuid == "-h" or uuid == "--help"
     puts head_banner
-    puts "Usage: arv view [uuid] [fields...]\n\n"
+    puts "Usage: arv get [uuid] [fields...]\n\n"
     puts "Fetch the specified Arvados object, select the specified fields, \n"
     puts "and print a text representation (json or yaml, use --format).\n"
     exit 255

commit 5ba12c5e842c926a38fad477d890ccbf9e96278d
Merge: b735534 45f10d8
Author: Joshua Randall <joshua.randall at sanger.ac.uk>
Date:   Sat Sep 5 00:20:25 2015 +0100

    Merge remote-tracking branch 'hgi/develop' into fix/7205-arv-edit-tty-check
    
    Conflicts:
    	sdk/cli/bin/arv

diff --cc sdk/cli/bin/arv
index b757855,252d267..cf1e732
--- a/sdk/cli/bin/arv
+++ b/sdk/cli/bin/arv
@@@ -295,9 -290,44 +290,39 @@@ def fetch_rsc_obj client, arvados, rsc
    end
  
    if remaining_opts.length > 0
-     oldobj.select! { |k, v| remaining_opts.include? k }
+     obj.select! { |k, v| remaining_opts.include? k }
    end
  
+   return obj
+ end
+ 
+ def get_obj_content obj, global_opts
+   content = case global_opts[:format]
+             when 'json'
+               Oj.dump(obj, :indent => 1)
+             when 'yaml'
+               obj.to_yaml
+             else
+               abort "Unrecognized format #{global_opts[:format]}"
+             end
+   return content
+ end
+ 
+ def arv_edit client, arvados, global_opts, remaining_opts
+   uuid = remaining_opts.shift
+   if uuid.nil? or uuid == "-h" or uuid == "--help"
+     puts head_banner
+     puts "Usage: arv edit [uuid] [fields...]\n\n"
+     puts "Fetch the specified Arvados object, select the specified fields, \n"
+     puts "open an interactive text editor on a text representation (json or\n"
+     puts "yaml, use --format) and then update the object.  Will use 'nano'\n"
+     puts "by default, customize with the EDITOR or VISUAL environment variable.\n"
+     exit 255
+   end
+ 
 -  if not $stdout.tty?
 -    puts "Not connected to a TTY, cannot run interactive editor."
 -    exit 1
 -  end
 -
+   rsc = lookup_uuid_rsc arvados, uuid
+   oldobj = fetch_rsc_obj client, arvados, rsc, uuid, remaining_opts
+ 
    edit_and_commit_object oldobj, uuid, global_opts do |newobj|
      newobj.select! {|k| newobj[k] != oldobj[k]}
      if !newobj.empty?

commit 45f10d80d1b584808a6e375214b5be6bc7d2a730
Merge: df9e166 8e2ad73
Author: Joshua C. Randall <jcrandall at alum.mit.edu>
Date:   Fri Sep 4 10:55:37 2015 +0100

    Merge pull request #2 from wtsi-hgi/feature/arv-view
    
    Feature/arv view


commit 8e2ad737e429bc263620859468da3835708258e2
Author: Joshua Randall <joshua.randall at sanger.ac.uk>
Date:   Fri Sep 4 02:22:45 2015 +0100

    Adds `arv view` subcommand
    
    Implements `arv view` feature as in https://arvados.org/issues/7204
    
    Refactors portions of arv_edit into separate functions so arv_view
    can share them.

diff --git a/sdk/cli/bin/arv b/sdk/cli/bin/arv
index 41ee7b8..252d267 100755
--- a/sdk/cli/bin/arv
+++ b/sdk/cli/bin/arv
@@ -85,7 +85,7 @@ def init_config
 end
 
 
-subcommands = %w(copy create edit keep pipeline run tag ws)
+subcommands = %w(copy create edit keep pipeline run tag view ws)
 
 def exec_bin bin, opts
   @bin_path = `which #{bin}`.strip
@@ -101,6 +101,8 @@ def check_subcommands client, arvados, subcommand, global_opts, remaining_opts
     arv_create client, arvados, global_opts, remaining_opts
   when 'edit'
     arv_edit client, arvados, global_opts, remaining_opts
+  when 'view'
+    arv_view client, arvados, global_opts, remaining_opts
   when 'copy', 'tag', 'ws', 'run'
     exec_bin "arv-#{subcommand}", remaining_opts
   when 'keep'
@@ -158,14 +160,7 @@ end
 
 def edit_and_commit_object initial_obj, tmp_stem, global_opts, &block
 
-  content = case global_opts[:format]
-            when 'json'
-              Oj.dump(initial_obj, :indent => 1)
-            when 'yaml'
-              initial_obj.to_yaml
-            else
-              abort "Unrecognized format #{global_opts[:format]}"
-            end
+  content = get_obj_content initial_obj, global_opts
 
   tmp_file = Tempfile.new([tmp_stem, ".#{global_opts[:format]}"])
   tmp_file.write(content)
@@ -254,25 +249,7 @@ def check_response result
   results
 end
 
-def arv_edit client, arvados, global_opts, remaining_opts
-  uuid = remaining_opts.shift
-  if uuid.nil? or uuid == "-h" or uuid == "--help"
-    puts head_banner
-    puts "Usage: arv edit [uuid] [fields...]\n\n"
-    puts "Fetch the specified Arvados object, select the specified fields, \n"
-    puts "open an interactive text editor on a text representation (json or\n"
-    puts "yaml, use --format) and then update the object.  Will use 'nano'\n"
-    puts "by default, customize with the EDITOR or VISUAL environment variable.\n"
-    exit 255
-  end
-
-  if not $stdout.tty?
-    puts "Not connected to a TTY, cannot run interactive editor."
-    exit 1
-  end
-
-  # determine controller
-
+def lookup_uuid_rsc arvados, uuid
   m = /([a-z0-9]{5})-([a-z0-9]{5})-([a-z0-9]{15})/.match uuid
   if !m
     if /^[a-f0-9]{32}/.match uuid
@@ -295,6 +272,11 @@ def arv_edit client, arvados, global_opts, remaining_opts
     abort "Could not determine resource type #{m[2]}"
   end
 
+  return rsc
+end
+
+def fetch_rsc_obj client, arvados, rsc, uuid, remaining_opts
+
   begin
     result = client.execute(:api_method => eval('arvados.' + rsc + '.get'),
                             :parameters => {"uuid" => uuid},
@@ -302,15 +284,50 @@ def arv_edit client, arvados, global_opts, remaining_opts
                             :headers => {
                               authorization: 'OAuth2 '+ENV['ARVADOS_API_TOKEN']
                             })
-    oldobj = check_response result
+    obj = check_response result
   rescue => e
     abort "Server error: #{e}"
   end
 
   if remaining_opts.length > 0
-    oldobj.select! { |k, v| remaining_opts.include? k }
+    obj.select! { |k, v| remaining_opts.include? k }
+  end
+
+  return obj
+end
+
+def get_obj_content obj, global_opts
+  content = case global_opts[:format]
+            when 'json'
+              Oj.dump(obj, :indent => 1)
+            when 'yaml'
+              obj.to_yaml
+            else
+              abort "Unrecognized format #{global_opts[:format]}"
+            end
+  return content
+end
+
+def arv_edit client, arvados, global_opts, remaining_opts
+  uuid = remaining_opts.shift
+  if uuid.nil? or uuid == "-h" or uuid == "--help"
+    puts head_banner
+    puts "Usage: arv edit [uuid] [fields...]\n\n"
+    puts "Fetch the specified Arvados object, select the specified fields, \n"
+    puts "open an interactive text editor on a text representation (json or\n"
+    puts "yaml, use --format) and then update the object.  Will use 'nano'\n"
+    puts "by default, customize with the EDITOR or VISUAL environment variable.\n"
+    exit 255
   end
 
+  if not $stdout.tty?
+    puts "Not connected to a TTY, cannot run interactive editor."
+    exit 1
+  end
+
+  rsc = lookup_uuid_rsc arvados, uuid
+  oldobj = fetch_rsc_obj client, arvados, rsc, uuid, remaining_opts
+
   edit_and_commit_object oldobj, uuid, global_opts do |newobj|
     newobj.select! {|k| newobj[k] != oldobj[k]}
     if !newobj.empty?
@@ -331,6 +348,24 @@ def arv_edit client, arvados, global_opts, remaining_opts
   exit 0
 end
 
+def arv_view client, arvados, global_opts, remaining_opts
+  uuid = remaining_opts.shift
+  if uuid.nil? or uuid == "-h" or uuid == "--help"
+    puts head_banner
+    puts "Usage: arv view [uuid] [fields...]\n\n"
+    puts "Fetch the specified Arvados object, select the specified fields, \n"
+    puts "and print a text representation (json or yaml, use --format).\n"
+    exit 255
+  end
+
+  rsc = lookup_uuid_rsc arvados, uuid
+  obj = fetch_rsc_obj client, arvados, rsc, uuid, remaining_opts
+  content = get_obj_content obj, global_opts
+
+  puts content
+  exit 0
+end
+
 def arv_create client, arvados, global_opts, remaining_opts
   types = resource_types(arvados.discovery_document)
   create_opts = Trollop::options do

commit ae0f6b92c3c302757ff7e81239bd7b41a4430e70
Author: Joshua Randall <joshua.randall at sanger.ac.uk>
Date:   Thu Sep 3 18:40:50 2015 +0100

    Adds error handling for command not found
    
    Raises a "command not found" error if arv-* commands are not
    found

diff --git a/sdk/cli/bin/arv b/sdk/cli/bin/arv
index 36ec037..41ee7b8 100755
--- a/sdk/cli/bin/arv
+++ b/sdk/cli/bin/arv
@@ -87,6 +87,14 @@ end
 
 subcommands = %w(copy create edit keep pipeline run tag ws)
 
+def exec_bin bin, opts
+  @bin_path = `which #{bin}`.strip
+  if @bin_path.empty?
+    raise "#{bin}: command not found"
+  end
+  exec @bin_path, *opts
+end
+
 def check_subcommands client, arvados, subcommand, global_opts, remaining_opts
   case subcommand
   when 'create'
@@ -94,17 +102,17 @@ def check_subcommands client, arvados, subcommand, global_opts, remaining_opts
   when 'edit'
     arv_edit client, arvados, global_opts, remaining_opts
   when 'copy', 'tag', 'ws', 'run'
-    exec `which arv-#{subcommand}`.strip, *remaining_opts
+    exec_bin "arv-#{subcommand}", remaining_opts
   when 'keep'
     @sub = remaining_opts.shift
     if ['get', 'put', 'ls', 'normalize'].index @sub then
       # Native Arvados
-      exec `which arv-#{@sub}`.strip, *remaining_opts
+      exec_bin "arv-#{@sub}", remaining_opts
     elsif ['less', 'check'].index @sub then
       # wh* shims
-      exec `which wh#{@sub}`.strip, *remaining_opts
+      exec_bin "wh#{@sub}", remaining_opts
     elsif @sub == 'docker'
-      exec `which arv-keepdocker`.strip, *remaining_opts
+      exec_bin "arv-keepdocker", remaining_opts
     else
       puts "Usage: arv keep [method] [--parameters]\n"
       puts "Use 'arv keep [method] --help' to get more information about specific methods.\n\n"
@@ -114,7 +122,7 @@ def check_subcommands client, arvados, subcommand, global_opts, remaining_opts
   when 'pipeline'
     sub = remaining_opts.shift
     if sub == 'run'
-      exec `which arv-run-pipeline-instance`.strip, *remaining_opts
+      exec_bin "arv-run-pipeline-instance", remaining_opts
     else
       puts "Usage: arv pipeline [method] [--parameters]\n"
       puts "Use 'arv pipeline [method] --help' to get more information about specific methods.\n\n"

commit df9e166a5ffc4aa79658bec1a5d552a3b413f0d8
Merge: 85706e0 1fea1b7
Author: Joshua C. Randall <jcrandall at alum.mit.edu>
Date:   Mon Mar 23 17:50:49 2015 +0000

    Merge pull request #1 from curoverse/master
    
    pulling from upstream


-----------------------------------------------------------------------


hooks/post-receive
diff --git a/sdk/cli/test/test_arv-get.rb b/sdk/cli/test/test_arv-get.rb
index 2dfb002..b9820d7 100644
--- a/sdk/cli/test/test_arv-get.rb
+++ b/sdk/cli/test/test_arv-get.rb
@@ -5,7 +5,7 @@ require 'yaml'
 # Black box tests for 'arv get' command.
 class TestArvGet < Minitest::Test
   # UUID for an Arvados object that does not exist
-  NON_EXISTANT_OBJECT_UUID = "qr1hi-tpzed-p9yk1lihjsgwew0"
+  NON_EXISTENT_OBJECT_UUID = "zzzzz-zzzzz-zzzzzzzzzzzzzzz"
   # Name of field of Arvados object that can store any (textual) value
   STORED_VALUE_FIELD_NAME = "name"
   # Name of UUID field of Arvados object
@@ -16,7 +16,7 @@ class TestArvGet < Minitest::Test
   # Tests that a valid Arvados object can be retrieved in a supported format
   # using: `arv get [uuid]`. Given all other `arv foo` commands return JSON
   # when no format is specified, JSON should be expected in this case.
-  def test_get_valid_object_no_format_specified()
+  def test_get_valid_object_no_format_specified
     stored_value = __method__.to_s
     uuid = create_arv_object_with_value(stored_value)
     out, err = capture_subprocess_io do
@@ -29,7 +29,7 @@ class TestArvGet < Minitest::Test
 
   # Tests that a valid Arvados object can be retrieved in JSON format using:
   # `arv get [uuid] --format json`.
-  def test_get_valid_object_json_format_specified()
+  def test_get_valid_object_json_format_specified
     stored_value = __method__.to_s
     uuid = create_arv_object_with_value(stored_value)
     out, err = capture_subprocess_io do
@@ -42,7 +42,7 @@ class TestArvGet < Minitest::Test
 
   # Tests that a valid Arvados object can be retrieved in YAML format using:
   # `arv get [uuid] --format yaml`.
-  def test_get_valid_object_yaml_format_specified()
+  def test_get_valid_object_yaml_format_specified
     stored_value = __method__.to_s
     uuid = create_arv_object_with_value(stored_value)
     out, err = capture_subprocess_io do
@@ -55,7 +55,7 @@ class TestArvGet < Minitest::Test
 
   # Tests that a subset of all fields of a valid Arvados object can be retrieved
   # using: `arv get [uuid] [fields...]`.
-  def test_get_valid_object_with_valid_fields()
+  def test_get_valid_object_with_valid_fields
     stored_value = __method__.to_s
     uuid = create_arv_object_with_value(stored_value)
     out, err = capture_subprocess_io do
@@ -70,7 +70,7 @@ class TestArvGet < Minitest::Test
   # Tests that the valid field is retrieved when both a valid and invalid field
   # are requested from a valid Arvados object, using:
   # `arv get [uuid] [fields...]`.
-  def test_get_valid_object_with_both_valid_and_invalid_fields()
+  def test_get_valid_object_with_both_valid_and_invalid_fields
     stored_value = __method__.to_s
     uuid = create_arv_object_with_value(stored_value)
     out, err = capture_subprocess_io do
@@ -84,7 +84,7 @@ class TestArvGet < Minitest::Test
 
   # Tests that no fields are retreived when no valid fields are requested from
   # a valid Arvados object, using: `arv get [uuid] [fields...]`.
-  def test_get_valid_object_with_no_valid_fields()
+  def test_get_valid_object_with_no_valid_fields
     stored_value = __method__.to_s
     uuid = create_arv_object_with_value(stored_value)
     out, err = capture_subprocess_io do
@@ -95,18 +95,18 @@ class TestArvGet < Minitest::Test
     assert_equal(0, arv_object.length)
   end
 
-  # Tests that an invalid (non-existant) Arvados object is not retrieved using:
-  # using: `arv get [non-existant-uuid]`.
-  def test_get_invalid_object()
+  # Tests that an invalid (non-existent) Arvados object is not retrieved using:
+  # using: `arv get [non-existent-uuid]`.
+  def test_get_invalid_object
     out, err = capture_subprocess_io do
-      refute(arv_get_json(NON_EXISTANT_OBJECT_UUID))
+      refute(arv_get_json(NON_EXISTENT_OBJECT_UUID))
     end
     refute_empty(err, "Expected error feedback on request for invalid object")
     assert_empty(out)
   end
 
   # Tests that help text exists using: `arv get --help`.
-  def test_help_exists()
+  def test_help_exists
     out, err = capture_subprocess_io do
 #      assert(arv_get_default("--help"), "Expected exit code 0: #{$?}")
        #XXX: Exit code given is 255. It probably should be 0, which seems to be

commit dd4d5ce9b5bbcf0ec18698f604a4d666f37fb9b9
Author: Colin Nolan <colin.nolan at sanger.ac.uk>
Date:   Tue Sep 22 16:07:57 2015 +0100

    7204: Removed assertion of success exit code for `arv get --help`.
    
    Exit code given for `arv get --help` is 255. It probably should be 0,
    which seems to be standard elsewhere. However, 255 is in line with
    other `arv` commands (e.g. see `arv edit`) so ignoring the problem.

diff --git a/sdk/cli/test/test_arv-get.rb b/sdk/cli/test/test_arv-get.rb
index c0f9146..76b110a 100644
--- a/sdk/cli/test/test_arv-get.rb
+++ b/sdk/cli/test/test_arv-get.rb
@@ -6,6 +6,12 @@ require 'yaml'
 class TestArvGet < Minitest::Test
   # UUID for an Arvados object that does not exist
   NON_EXISTANT_OBJECT_UUID = "qr1hi-tpzed-p8yk1lihjsgwew0"
+  # Name of field of Arvados object that can store any (textual) value
+  STORED_VALUE_FIELD_NAME = "name"
+  # Name of UUID field of Arvados object
+  UUID_FIELD_NAME = "uuid"
+  # Name of an invalid field of Arvados object
+  INVALID_FIELD_NAME = "invalid"
 
   # Tests that a valid Arvados object can be retrieved in JSON format using:
   # `arv get [uuid] --format json`.
@@ -16,7 +22,8 @@ class TestArvGet < Minitest::Test
       arv_get(uuid, '--format', 'json')
     end
     assert_empty(err)
-    assert(does_arv_object_as_json_use_value(out, stored_value))
+    arv_object = parse_json_arv_object(out)
+    assert(has_field_with_value(arv_object, STORED_VALUE_FIELD_NAME, stored_value))
   end
 
   # Tests that a valid Arvados object can be retrieved in YAML format using:
@@ -28,11 +35,13 @@ class TestArvGet < Minitest::Test
       arv_get(uuid, '--format', 'yaml')
     end
     assert_empty(err)
-    assert(does_arv_object_as_yaml_use_value(out, stored_value))
+    arv_object = parse_yaml_arv_object(out)
+    assert(has_field_with_value(arv_object, STORED_VALUE_FIELD_NAME, stored_value))
   end
 
   # Tests that a valid Arvados object can be retrieved in a supported format
-  # using: `arv get [uuid]`.
+  # using: `arv get [uuid]`. Given all other `arv foo` commands return JSON
+  # when no format is specified, JSON should be expected in this case.
   def test_get_valid_object_no_format()
     stored_value = __method__
     uuid = create_arv_object_with_value(stored_value)
@@ -40,47 +49,59 @@ class TestArvGet < Minitest::Test
       arv_get(uuid)
     end
     assert_empty(err)
-    assert(does_arv_object_as_yaml_use_value(out, stored_value) ||
-        does_arv_object_as_json_use_value(out, stored_value))
+    arv_object = parse_json_arv_object(out)
+    assert(has_field_with_value(arv_object, STORED_VALUE_FIELD_NAME, stored_value))
   end
 
-  # TODO: Add tests for selecting specific fields
+  # Tests that a subset of all fields of a valid Arvados object can be retrieved
+  # using: `arv get [uuid] [fields...]`.
   def test_get_valid_object_with_specific_valid_fields()
-    # TODO
+    stored_value = __method__
+    uuid = create_arv_object_with_value(stored_value)
+    out, err = capture_subprocess_io do
+      arv_get(uuid, STORED_VALUE_FIELD_NAME, UUID_FIELD_NAME, "--format", "json")
+    end
+    assert_empty(err)
+    arv_object = parse_json_arv_object(out)
+    assert(has_field_with_value(arv_object, STORED_VALUE_FIELD_NAME, stored_value))
+    assert(has_field_with_value(arv_object, UUID_FIELD_NAME, uuid))
   end
 
-  # TODO: Add tests for selecting specific fields
+  # Tests that the valid field is retrieved when both a valid and invalid field
+  # are requested from a valid Arvados object, using:
+  # `arv get [uuid] [fields...]`.
   def test_get_valid_object_with_both_specific_valid_and_invalid_fields()
-    # TODO
-  end
-
-  # Tests that an valid Arvados object is not retrieved when specifying an
-  # invalid format: `arv get [uuid] --format invalid`.
-  def test_get_object_invalid_format()
     stored_value = __method__
     uuid = create_arv_object_with_value(stored_value)
     out, err = capture_subprocess_io do
-      arv_get(uuid, '--format', 'invalid')
+      arv_get(uuid, STORED_VALUE_FIELD_NAME, INVALID_FIELD_NAME, "--format", "json")
     end
-    refute_empty(err)
-    assert_empty(out)
+    assert_empty(err)
+    arv_object = parse_json_arv_object(out)
+    assert(has_field_with_value(arv_object, STORED_VALUE_FIELD_NAME, stored_value))
+    refute(has_field_with_value(arv_object, INVALID_FIELD_NAME, stored_value))
   end
 
-  # Tests that an invalid (non-existant) Arvados object is not retrieved using:
-  # using: `arv get [non-existant-uuid] --format json`.
-  def test_get_invalid_object_json_format()
+  # Tests that no fields are retreived when no valid fields are requested from
+  # a valid Arvados object, using: `arv get [uuid] [fields...]`.
+  def test_get_valid_object_with_no_specific_valid_fields()
+    stored_value = __method__
+    uuid = create_arv_object_with_value(stored_value)
     out, err = capture_subprocess_io do
-      arv_get(NON_EXISTANT_OBJECT_UUID, '--format', 'json')
+      arv_get(uuid, INVALID_FIELD_NAME, "--format", "json")
     end
-    refute_empty(err)
-    assert_empty(out)
+    assert_empty(err)
+    arv_object = parse_json_arv_object(out)
+    assert_equal(0, arv_object.fixnum)
   end
 
-  # Tests that an invalid (non-existant) Arvados object is not retrieved using:
-  # using: `arv get [non-existant-uuid] --format yaml`.
-  def test_get_invalid_object_yaml_format()
+  # Tests that an valid Arvados object is not retrieved when specifying an
+  # invalid format: `arv get [uuid] --format invalid`.
+  def test_get_valid_object_invalid_format()
+    stored_value = __method__
+    uuid = create_arv_object_with_value(stored_value)
     out, err = capture_subprocess_io do
-      arv_get(NON_EXISTANT_OBJECT_UUID, '--format', 'yaml')
+      arv_get(uuid, '--format', 'invalid')
     end
     refute_empty(err)
     assert_empty(out)
@@ -88,30 +109,14 @@ class TestArvGet < Minitest::Test
 
   # Tests that an invalid (non-existant) Arvados object is not retrieved using:
   # using: `arv get [non-existant-uuid]`.
-  def test_get_invalid_object_no_format()
+  def test_get_invalid_object()
     out, err = capture_subprocess_io do
-      arv_get(NON_EXISTANT_OBJECT_UUID)
+      arv_get(NON_EXISTANT_OBJECT_UUID, "--format", "json")
     end
     refute_empty(err)
     assert_empty(out)
   end
 
-  # Tests that an invalid (non-existant) Arvados object is not retrieved when
-  # specifying an invalid format:
-  # `arv get [non-existant-uuid] --format invalid`.
-  def test_get_object_invalid_format()
-    out, err = capture_subprocess_io do
-      arv_get(NON_EXISTANT_OBJECT_UUID, '--format', 'invalid')
-    end
-    refute_empty(err)
-    assert_empty(out)
-  end
-
-  # TODO: Test what happens when valid object but invalid fields
-  def test_get_valid_object_with_specific_invalid_fields()
-    # TODO
-  end
-
   protected
   # Runs 'arv get <varargs>' with given arguments.
   def arv_get(*args)
@@ -131,33 +136,36 @@ class TestArvGet < Minitest::Test
       return out
   end
 
-  # Checks whether the Arvados object, represented in JSON format, uses the
-  # given value.
-  def does_arv_object_as_json_use_value(obj, value)
+  # Parses the given JSON representation of an Arvados object, returning
+  # an equivalent Ruby representation (a hash map).
+  def parse_json_arv_object(arvObjectAsJson)
     begin
-      parsed = JSON.parse(obj)
-      return does_arv_object_as_ruby_object_use_value(parsed, value)
+      parsed = JSON.parse(arvObjectAsJson)
+      assert(parsed.instance_of?(Hash))
+      return parsed
     rescue JSON::ParserError => e
       raise "Invalid JSON representation of Arvados object"
     end
   end
 
-  # Checks whether the Arvados object, represented in YAML format, uses the
-  # given value.
-  def does_arv_object_as_yaml_use_value(obj, value)
+  # Parses the given JSON representation of an Arvados object, returning
+  # an equivalent Ruby representation (a hash map).
+  def parse_yaml_arv_object(arvObjectAsYaml)
     begin
-      parsed = YAML.load(obj)
-      return does_arv_object_as_ruby_object_use_value(parsed, value)
+      parsed = YAML.load(arvObjectAsYaml)
+      assert(parsed.instance_of?(Hash))
+      return parsed
     rescue
       raise "Invalid YAML representation of Arvados object"
     end
   end
 
-  # Checks whether the Arvados object, represented as a Ruby object, uses the
-  # given value.
-  def does_arv_object_as_ruby_object_use_value(obj, value)
-    assert(parsed.instance_of?(Hash))
-    stored_value = obj["name"]
-    return (value == stored_value)
+  # Checks whether the given Arvados object has the given expected value for the
+  # specified field.
+  def has_field_with_value(arvObjectAsHash, fieldName, expectedValue)
+    if !arvObjectAsHash.has_key?(fieldName)
+      return false
+    end
+    return (arvObjectAsHash[fieldName] == expectedValue)
   end
 end

commit 7e6304bf646aaeb38196d24ce98c8bafc212e144
Author: Colin Nolan <colin.nolan at sanger.ac.uk>
Date:   Fri Sep 18 19:05:41 2015 +0100

    7204: Stubbed more test cases for `arg get` to cover use for only getting specific fields.

-- 




More information about the arvados-commits mailing list